@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 469 2005-07-19 00:23:53Z svn $
+ * $Id: UploadItemList.h 479 2005-07-23 12:53:27Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMLIST_H
@@ -61,16 +61,18 @@ public:
                    const char *file_dir, const char *thumb_dir,
                    apr_size_t total_number_limit, apr_uint64_t total_size_limit);
     void add(const char *file_path, bool is_make_thumb=false);
-    apr_size_t size();
-    apr_size_t thumb_size();
-    apr_uint64_t total_file_size();
-    apr_time_t get_mtime();
+    apr_size_t size() const;
+    apr_size_t thumb_size() const;
+    apr_uint64_t total_file_size() const;
+    apr_time_t get_mtime() const;
     void remove(const char *file_path, const char *password);
     TemplateExecutor::variable *to_varray(apr_pool_t *pool,
-                                          apr_size_t start, apr_size_t size);
+                                          apr_size_t start,
+                                          apr_size_t size) const;
     TemplateExecutor::variable *to_thumb_varray(apr_pool_t *pool,
-                                                apr_size_t start, apr_size_t size);
-    item_info **to_array(apr_pool_t *pool, apr_size_t start, apr_size_t size);
+                                                apr_size_t start,
+                                                apr_size_t size) const;
+    item_info **to_array(apr_pool_t *pool, apr_size_t start, apr_size_t size) const;
 
     static UploadItemList *load(apr_pool_t *pool,
                                 const char *file_dir, const char *thumb_dir,
@@ -105,8 +107,8 @@ private:
     UploadItemList &operator=(const UploadItemList&);
 
     void init();
-    item_iterator begin();
-    item_iterator end();
+    item_iterator begin() const;
+    item_iterator end() const;
     void remove(item_info *info);
 
     apr_pool_t *pool_;
