@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BinString.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: BinString.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "BinString.h"
@@ -89,7 +89,7 @@ void BinString::reserve(apr_size_t size)
  *****************************************************************************/
 char *BinString::alloc(apr_size_t size)
 {
-    char *buffer = static_cast<char *>(malloc(sizeof(char *)*size));
+    char *buffer = reinterpret_cast<char *>(malloc(sizeof(char *)*size));
 
     if (buffer == NULL) {
         throw "γݤ˼Ԥޤ";
