@@ -24,10 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 468 2005-07-18 10:11:42Z svn $
+ * $Id: TemplateExecutor.cpp 480 2005-07-23 14:46:26Z svn $
  *****************************************************************************/
 
 #include "TemplateExecutor.h"
+#include "Misc.h"
 
 #include "http_protocol.h"
 #include "apr_strings.h"
@@ -121,9 +122,9 @@ void TemplateExecutor::exec_foreach(handle *h, node *node)
     variable *array_var = h->vmap->at(node->branch.center->i_val);
     apr_size_t index_id = node->branch.left->i_val;
 
-    if (array_var == NULL) {
+    if (UNLIKELY(array_var == NULL)) {
         throw "Ƥʤѿ򻲾Ȥޤ";
-    } else if (array_var->type != ARRAY) {
+    } else if (UNLIKELY(array_var->type != ARRAY)) {
         throw "ɬפʾˤ¾ѿꤵƤޤ";
     }
 
@@ -174,7 +175,7 @@ void TemplateExecutor::exec_print(handle *h, node *node)
             var = get_var(h, node->branch.left);
             goto VAR;
         VAR:
-            if (var == NULL) {
+            if (UNLIKELY(var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
             }
 
@@ -231,7 +232,7 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
     case TemplateParser::IDENTIFIER:        // IDENTIFIER
         var = h->vmap->at(node->i_val);
 
-        if (var == NULL) {
+        if (UNLIKELY(var == NULL)) {
             throw "Ƥʤѿ򻲾Ȥޤ";
         }
 
@@ -246,7 +247,7 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
         case TemplateParser::ARRAY_REF:     // []
         case TemplateParser::HASH_REF:      // .
             ref_var = get_var(h, node->branch.right);
-            if (ref_var == NULL) {
+            if (UNLIKELY(ref_var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
             }
 
@@ -348,9 +349,9 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
             ident_id = node->branch.left->i_val;
             var = h->vmap->at(ident_id);
 
-            if (var == NULL) {
+            if (UNLIKELY(var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
-            } else if (var->type != SCALAR) {
+            } else if (UNLIKELY(var->type != SCALAR)) {
                 throw "SCALAR ɬפʾǤʳѿĤޤ";
             }
 
@@ -365,9 +366,9 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
             ident_id = node->branch.right->i_val;
             var = h->vmap->at(ident_id);
 
-            if (var == NULL) {
+            if (UNLIKELY(var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
-            } else if (var->type != SCALAR) {
+            } else if (UNLIKELY(var->type != SCALAR)) {
                 throw "SCALAR ɬפʾǤʳѿĤޤ";
             }
 
@@ -428,7 +429,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
         var = h->vmap->at(node->branch.left->i_val);
         if (var == NULL) {
             break;
-        } else if (var->type != ARRAY) {
+        } else if (UNLIKELY(var->type != ARRAY)) {
             throw "ɬפʾˤ¾ѿꤵƤޤ";
         }
 
@@ -441,7 +442,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
 
             if (var == NULL) {
                 break;
-            } else if (var->type != HASH) {
+            } else if (UNLIKELY(var->type != HASH)) {
                 throw "Ϣɬפʾˤ¾ѿꤵƤޤ";
             }
             key = node->branch.right->branch.right->s_val;
@@ -453,7 +454,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
         var = h->vmap->at(node->branch.left->i_val);
         if (var == NULL) {
             break;
-        } else if (var->type != HASH) {
+        } else if (UNLIKELY(var->type != HASH)) {
             throw "Ϣɬפʾˤ¾ѿꤵƤޤ";
         }
 
@@ -463,12 +464,12 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
                                                         APR_HASH_KEY_STRING));
         break;
     default:
-        if (var == NULL) {
+        if (UNLIKELY(var == NULL)) {
             throw "ХǤ";
         }
     }
 
-    if (var == NULL) {
+    if (UNLIKELY(var == NULL)) {
         throw "Ƥʤѿ򻲾Ȥޤ";
     }
 
