@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateVariableCreator.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: TemplateVariableCreator.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "TemplateVariableCreator.h"
@@ -67,9 +67,9 @@ TemplateVariableCreator::variable *TemplateVariableCreator::create(apr_pool_t *p
 {
     variable *var;
 
-    var = static_cast<variable *>(apr_palloc(pool, sizeof(variable)));
+    var = reinterpret_cast<variable *>(apr_palloc(pool, sizeof(variable)));
     var->type = TemplateExecutor::SCALAR;
-    var->s_val = static_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
+    var->s_val = reinterpret_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
     var->s_val->type = TemplateExecutor::STRING;
     var->s_val->s_val = str;
 
@@ -80,7 +80,7 @@ TemplateVariableCreator::variable *TemplateVariableCreator::create(apr_pool_t *p
 {
     variable *var;
 
-    var = static_cast<variable *>(apr_palloc(pool, sizeof(variable)));
+    var = reinterpret_cast<variable *>(apr_palloc(pool, sizeof(variable)));
     var->type = TemplateExecutor::HASH;
     var->h_val = hash;
 
@@ -91,7 +91,7 @@ TemplateVariableCreator::variable *TemplateVariableCreator::create(apr_pool_t *p
 {
     variable *var;
 
-    var = static_cast<variable *>(apr_palloc(pool, sizeof(variable)));
+    var = reinterpret_cast<variable *>(apr_palloc(pool, sizeof(variable)));
     var->type = TemplateExecutor::ARRAY;
     var->a_val = array;
 
