@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 468 2005-07-18 10:11:42Z svn $
+ * $Id: UploadItem.cpp 479 2005-07-23 12:53:27Z svn $
  *****************************************************************************/
 
 #include "UploadItem.h"
@@ -93,47 +93,47 @@ UploadItem::header *UploadItem::set_data(const char *file_path, header *new_head
     return old_header;
 }
 
-UploadItem::header *UploadItem::get_header()
+UploadItem::header *UploadItem::get_header() const
 {
     return header_;
 }
 
-const char *UploadItem::get_file_path()
+const char *UploadItem::get_file_path() const
 {
     return file_path_;
 }
 
-const char *UploadItem::get_file_name()
+const char *UploadItem::get_file_name() const
 {
     return header_->file_name;
 }
 
-const char *UploadItem::get_comment()
+const char *UploadItem::get_comment() const
 {
     return header_->comment;
 }
 
-const char *UploadItem::get_remove_pass()
+const char *UploadItem::get_remove_pass() const
 {
     return header_->remove_pass;
 }
 
-const char *UploadItem::get_download_pass()
+const char *UploadItem::get_download_pass() const
 {
     return header_->download_pass;
 }
 
-const char *UploadItem::get_file_size()
+const char *UploadItem::get_file_size() const
 {
     return size_str(pool_, header_->file_size);
 }
 
-const char *UploadItem::get_file_mime()
+const char *UploadItem::get_file_mime() const
 {
     return header_->file_mime;
 }
 
-const char *UploadItem::get_time()
+const char *UploadItem::get_time() const
 {
     apr_time_exp_t time_exp;
     char *time_str;
