@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 468 2005-07-18 10:11:42Z svn $
+ * $Id: UploadItemList.cpp 479 2005-07-23 12:53:27Z svn $
  *****************************************************************************/
 
 #include "UploadItemList.h"
@@ -100,22 +100,22 @@ void UploadItemList::add(const char *file_path, bool is_make_thumb)
     }
 }
 
-apr_size_t UploadItemList::size()
+apr_size_t UploadItemList::size() const
 {
     return ilist_.size();
 }
 
-apr_size_t UploadItemList::thumb_size()
+apr_size_t UploadItemList::thumb_size() const
 {
     return tlist_.size();
 }
 
-apr_uint64_t UploadItemList::total_file_size()
+apr_uint64_t UploadItemList::total_file_size() const
 {
     return total_size_;
 }
 
-apr_time_t UploadItemList::get_mtime()
+apr_time_t UploadItemList::get_mtime() const
 {
     return mtime_;
 }
@@ -144,7 +144,7 @@ void UploadItemList::remove(const char *file_path, const char *password)
 
 TemplateExecutor::variable *UploadItemList::to_varray(apr_pool_t *pool,
                                                       apr_size_t start,
-                                                      apr_size_t size)
+                                                      apr_size_t size) const
 {
     apr_array_header_t *array = apr_array_make(pool, static_cast<int>(size),
                                                static_cast<int>(sizeof(TemplateExecutor::variable *)));
@@ -168,7 +168,7 @@ TemplateExecutor::variable *UploadItemList::to_varray(apr_pool_t *pool,
 
 TemplateExecutor::variable *UploadItemList::to_thumb_varray(apr_pool_t *pool,
                                                             apr_size_t start,
-                                                            apr_size_t size)
+                                                            apr_size_t size) const
 {
     apr_array_header_t *array = apr_array_make(pool, static_cast<int>(size),
                                                static_cast<int>(sizeof(TemplateExecutor::variable *)));
@@ -190,7 +190,7 @@ TemplateExecutor::variable *UploadItemList::to_thumb_varray(apr_pool_t *pool,
 
 UploadItemList::item_info **UploadItemList::to_array(apr_pool_t *pool,
                                                      apr_size_t start,
-                                                     apr_size_t size)
+                                                     apr_size_t size) const
 {
     item_iterator i = begin();
     item_info **item_list;
@@ -308,12 +308,12 @@ void UploadItemList::init()
     mtime_ = apr_time_now();
 }
 
-inline UploadItemList::item_iterator UploadItemList::begin()
+inline UploadItemList::item_iterator UploadItemList::begin() const
 {
     return ilist_.begin();
 }
 
-inline UploadItemList::item_iterator UploadItemList::end()
+inline UploadItemList::item_iterator UploadItemList::end() const
 {
     return ilist_.end();
 }
