@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: UploadItemReader.cpp 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #include "UploadItemReader.h"
@@ -67,13 +67,12 @@ UploadItem::header *UploadItemReader::read(const char *file_name,
         throw "åץɥե̾ǤޤǤ";
     }
 
-
     if (apr_file_open(file, file_path, APR_READ|APR_BINARY|APR_SENDFILE_ENABLED,
                       APR_OS_DEFAULT, pool) != APR_SUCCESS) {
         throw "åץɥե򳫤ޤǤ";
     }
 
-    header = static_cast<UploadItem::header *>(apr_pcalloc(pool, sizeof(UploadItem::header)));
+    header = reinterpret_cast<UploadItem::header *>(apr_pcalloc(pool, sizeof(UploadItem::header)));
     size = sizeof(UploadItem::header);
     if ((apr_file_read(*file, header, &size) != APR_SUCCESS) ||
         (size != sizeof(UploadItem::header))) {
