@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.cpp 329 2005-04-24 04:12:45Z svn $
+ * $Id: UploadItemWriter.cpp 441 2005-07-08 20:14:06Z svn $
  *****************************************************************************/
 
 #include "UploadItemWriter.h"
@@ -116,11 +116,18 @@ const char *UploadItemWriter::create_file_name(apr_pool_t *pool, const char *fil
 
 #include "RFC1867ParserImpl.h"
 #include "UploadItem.h"
+#include "UploadItemCreator.h"
 
 static const apr_size_t  BUFSIZE        = 256;
 static const char FILE_DIR[]            = "/tmp";
 static const char CONTENT_TYPE_TMPL[]   = "multipart/form-data; boundary=%s";
 
+// ߡ
+char *ap_escape_html(apr_pool_t *pool, const char *str)
+{
+    return const_cast<char *>(str);
+}
+
 void usage(const char *prog_name)
 {
     cerr << "Usage: " << prog_name << " <INPUT>" << endl;
@@ -129,15 +136,12 @@ void usage(const char *prog_name)
 int main(int argc, const char * const *argv)
 {
     char content_type[BUFSIZE];
-    UploadParser *parser;
     apr_pool_t *pool;
     apr_file_t *fd;
     apr_off_t offset;
-    UploadParser::query_map *qmap;
     UploadItem::header *header;
-    UploadItemWriter *writer;
     const char *tmp_path;
-    const char *file_name;
+    const char *file_path;
 
     apr_app_initialize(&argc, &argv, NULL);
     apr_pool_create(&pool, NULL);
@@ -160,23 +164,20 @@ int main(int argc, const char * const *argv)
             throw "ѤΥե seek ˼Ԥޤ";
         }
 
-        parser = new UploadParser(FILE_DIR, 10*1024*1024, 32*1024*1024, 5,
-                                  UploadItem::ITEM_HEADER_SIZE);
-        qmap = parser->parse(pool, fd,
-                             apr_psprintf(pool, CONTENT_TYPE_TMPL, content_type+2));
+        UploadParser parser(FILE_DIR, 10*1024*1024, 32*1024*1024, 5,
+                            UploadItem::ITEM_HEADER_SIZE);
 
-        writer = new UploadItemWriter(pool, FILE_DIR);
-        header = UploadItem::create_header(pool, qmap, &tmp_path);
-        file_name = writer->write(header, tmp_path);
-        cerr << "file_name = " << file_name << endl;
+        auto_ptr<UploadParser::query_map>
+            qmap(parser.parse(pool, fd,
+                              apr_psprintf(pool, CONTENT_TYPE_TMPL, content_type+2)));
 
-        UploadParser::clean_tmp_file(pool, qmap);
+        UploadItemWriter writer(pool, FILE_DIR);
+        header = UploadItemCreator::create_header(pool, qmap.get(), &tmp_path);
+
+        file_path = writer.write(header, tmp_path);
+
+        UploadParser::clean_tmp_file(pool, qmap.get());
         UploadItem::dump_header(header);
-        UploadParser::clear_map(qmap);
-
-        delete writer;
-        delete qmap;
-        delete parser;
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
