@@ -24,12 +24,14 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 480 2005-07-23 14:46:26Z svn $
+ * $Id: UploaderConfig.cpp 487 2005-08-04 18:28:09Z svn $
  *****************************************************************************/
 
 #include "UploaderConfig.h"
 #include "Misc.h"
 
+#include "apr_strings.h"
+
 #ifdef WIN32
 #include <Windows.h>
 #else
@@ -59,7 +61,7 @@ const apr_size_t UploaderConfig::ITEM_RELOAD_THRESHOLD  = 100;
 
 static apr_status_t finalize_config(void *data);
 #if APR_HAS_THREADS
-static apr_status_t finalize_rwlock(void *data);
+static apr_status_t finalize_lock(void *data);
 #endif
 
 
@@ -94,7 +96,7 @@ UploaderConfig::UploaderConfig()
       error_tmpl_pool(NULL),
       list_pool(NULL),
 #if APR_HAS_THREADS
-      rwlock(NULL),
+      lock(NULL),
 #endif
       is_init(false)
 {
@@ -115,7 +117,7 @@ void UploaderConfig::init(apr_pool_t *pool, apr_pool_t *tmp_pool)
     validate();
 
 #if APR_HAS_THREADS
-    init_rwlock(pool, tmp_pool);
+    init_lock(pool, tmp_pool);
 #endif
     load_list(pool);
 
@@ -207,7 +209,11 @@ UploadItemWriter *UploaderConfig::get_uwriter(apr_pool_t *pool)
 apr_status_t UploaderConfig::read_lock()
 {
 #if APR_HAS_THREADS
-    return apr_thread_rwlock_rdlock(rwlock);
+#ifdef LOCK_TYPE_MUTEX
+    return apr_thread_mutex_lock(lock);
+#else
+    return apr_thread_rwlock_rdlock(lock);
+#endif
 #else
     return APR_SUCCESS;
 #endif
@@ -216,7 +222,11 @@ apr_status_t UploaderConfig::read_lock()
 apr_status_t UploaderConfig::write_lock()
 {
 #if APR_HAS_THREADS
-    return apr_thread_rwlock_wrlock(rwlock);
+#ifdef LOCK_TYPE_MUTEX
+    return apr_thread_mutex_lock(lock);
+#else
+    return apr_thread_rwlock_wrlock(lock);
+#endif
 #else
     return APR_SUCCESS;
 #endif
@@ -225,7 +235,11 @@ apr_status_t UploaderConfig::write_lock()
 apr_status_t UploaderConfig::unlock()
 {
 #if APR_HAS_THREADS
-    return apr_thread_rwlock_unlock(rwlock);
+#ifdef LOCK_TYPE_MUTEX
+    return apr_thread_mutex_unlock(lock);
+#else
+    return apr_thread_rwlock_unlock(lock);
+#endif
 #else
     return APR_SUCCESS;
 #endif
@@ -250,13 +264,19 @@ void UploaderConfig::validate()
 }
 
 #if APR_HAS_THREADS
-void UploaderConfig::init_rwlock(apr_pool_t *pool, apr_pool_t *tmp_pool)
+void UploaderConfig::init_lock(apr_pool_t *pool, apr_pool_t *tmp_pool)
 {
-    if (apr_thread_rwlock_create(&rwlock, pool) != APR_SUCCESS) {
-        throw "Can not create rwlock.";
+#ifdef LOCK_TYPE_MUTEX
+    if (apr_thread_mutex_create(&lock, APR_THREAD_MUTEX_DEFAULT, pool) != APR_SUCCESS) {
+        throw "Can not create lock.";
     }
+#else
+    if (apr_thread_rwlock_create(&lock, pool) != APR_SUCCESS) {
+        throw "Can not create lock.";
+    }
+#endif
 
-    apr_pool_cleanup_register(pool, rwlock, apr_pool_cleanup_null, finalize_rwlock);
+    apr_pool_cleanup_register(pool, lock, apr_pool_cleanup_null, finalize_lock);
 }
 #endif
 
@@ -277,7 +297,6 @@ void UploaderConfig::update_list(apr_pool_t *pool, apr_pool_t *tmp_pool)
 {
     if (get_mtime(tmp_pool, file_dir) > item_list->get_mtime()) {
         try {
-            // äȴɡΨͤƤΰ֤ǥå(äѤᡩ)
             write_lock();
 
             load_list(pool);
@@ -311,7 +330,6 @@ void UploaderConfig::update_list(apr_pool_t *pool, apr_pool_t *tmp_pool)
         }
     } else if (remove_item_number++ == ITEM_RELOAD_THRESHOLD) {
         try {
-            // äȴɡΨͤƤΰ֤ǥå(äѤᡩ)
             write_lock();
 
             load_list(pool);
@@ -334,7 +352,8 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
 
     if (apr_file_open(&file, template_path, APR_READ,
                       APR_OS_DEFAULT, pool) != APR_SUCCESS) {
-        throw "ƥץ졼Ȥ open ˼Ԥޤ";
+        throw apr_psprintf(pool,
+                           "Failed to open page template (%s).", template_path);
     }
 
     try {
@@ -380,7 +399,9 @@ apr_time_t UploaderConfig::get_mtime(apr_pool_t *pool, const char *file_path)
     apr_finfo_t info;
 
     if (UNLIKELY(apr_stat(&info, file_path, APR_FINFO_MTIME, pool) != APR_SUCCESS)) {
-        throw "եޤϥǥ쥯ȥιǤޤǤ";
+        throw apr_psprintf(pool,
+                           "Failed to get information of file/directory (%s).",
+                           file_path);
     }
 
     return info.mtime;
@@ -401,12 +422,19 @@ apr_status_t finalize_config(void *data)
 }
 
 #if APR_HAS_THREADS
-apr_status_t finalize_rwlock(void *data)
+apr_status_t finalize_lock(void *data)
 {
-    apr_thread_rwlock_t *rwlock;
+#ifdef LOCK_TYPE_MUTEX
+    apr_thread_mutex_t *lock;
 
-    rwlock = reinterpret_cast<apr_thread_rwlock_t *>(data);
-    apr_thread_rwlock_destroy(rwlock);
+    lock = reinterpret_cast<apr_thread_mutex_t *>(data);
+    apr_thread_mutex_destroy(lock);
+#else
+    apr_thread_rwlock_t *lock;
+
+    lock = reinterpret_cast<apr_thread_rwlock_t *>(data);
+    apr_thread_rwlock_destroy(lock);
+#endif
 
     return APR_SUCCESS;
 }
